useBackdrop property
When true, renders using BackdropFilter so the shader samples from the scene behind this layer instead of the provided child.
Implementation
final bool useBackdrop;
When true, renders using BackdropFilter so the shader samples from the scene behind this layer instead of the provided child.
final bool useBackdrop;