FrostShaderLayer class
FrostShaderLayer A reusable overlay that renders a spreading-frost post-process over its child while letting the child continue to update/animate underneath.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- FrostShaderLayer
Constructors
- FrostShaderLayer({Key? key, required Widget child, FrostLayerController? controller, Duration duration = const Duration(milliseconds: 900), Curve curve = Curves.easeInOutCubic, double frostiness = 0.55, double blurAmount = 3.0, double ringWidth = 0.12, double ringIrregularity = 0.28, double ringNoiseScale = 1.2, double bloomStrength = 0.35, double bloomWidth = 12.0, Color bloomColor = const Color(0xCCBFE3FF), VoidCallback? onCompleted})
-
const
Properties
- bloomColor → Color
-
final
- bloomStrength → double
-
final
- bloomWidth → double
-
final
- blurAmount → double
-
final
- child → Widget
-
final
- controller → FrostLayerController?
-
final
- curve → Curve
-
final
- duration → Duration
-
final
- frostiness → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onCompleted → VoidCallback?
-
final
- ringIrregularity → double
-
final
- ringNoiseScale → double
-
final
- ringWidth → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< FrostShaderLayer> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited