widgets/spreading_frost_image_switcher library

Classes

SpreadingFrostController
Controller to start the frost transition from outside the widget.
SpreadingFrostImageSwitcher
An image switcher that plays a Spreading Frost transition when switching.