SpreadingFrostWidget class

SpreadingFrostWidget

A convenience wrapper around SpreadingFrostImageSwitcher that applies the spreading frost transition between two arbitrary widgets (not just images).

Usage:

All shader parameters are exposed for fine-tuning.

Inheritance

Constructors

SpreadingFrostWidget({Key? key, required Widget current, required Widget next, SpreadingFrostController? controller, Duration duration = const Duration(milliseconds: 900), Curve curve = Curves.easeInOut, double frostiness = 0.5, double blurAmount = 2.0, double ringWidth = 0.12, double ringIrregularity = 0.25, double ringNoiseScale = 1.0, double bloomStrength = 0.35, double bloomWidth = 10.0, Color bloomColor = const Color(0xCCFFFFFF), VoidCallback? onCompleted})
const

Properties

bloomColor Color
final
bloomStrength double
final
bloomWidth double
final
blurAmount double
final
controller SpreadingFrostController?
final
current Widget
final
curve Curve
final
duration Duration
final
frostiness double
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
next Widget
final
onCompleted VoidCallback?
final
ringIrregularity double
final
ringNoiseScale double
final
ringWidth double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited