lockToScreen property

bool lockToScreen
final

When true in non-backdrop mode, the raindrop pattern is anchored to screen space, so it does not move when this widget scrolls. The effect is still applied to this widget's child only.

Implementation

final bool lockToScreen;