useBackdrop property

bool useBackdrop
final

When true, use BackdropFilter + ImageFilter.shader to sample the pixels behind this widget (i.e. real backdrop). In this mode, child is rendered as the overlay content and is not used as the sampled image.

When false (default), the shader samples only the offscreen capture of its child via AnimatedSampler.

Implementation

final bool useBackdrop;